@@ -1,3 +1,5 @@
+#![allow(non_upper_case_globals)]
+
 use std::error::Error;
 use std::io;
 use std::str::FromStr;
@@ -5,7 +7,8 @@ use std::fmt::Display;
 
 pub type Er = anyhow::Error;
 pub type Res<T> = anyhow::Result<T>;
-pub type Report = Res<()>;
+pub type Maybe = Res<()>;
+pub const ok: Maybe = Ok(());
 
 pub fn cin<T>() -> Res<T> 
 where T: FromStr, <T as FromStr>::Err: Error + Send + Sync + 'static
